function OUT=loclzerr_CRC(Width,NSR0,DELTAnsr,Nnsr,Niter);

% Distribution histograms of the localization error for an IMPULSE
% over the interval INTERVAL for different
% noise-to-signal ratios from NSR0 to NSR0+DELTAnsr*(Nnsr-1).
% Width - parameter defining width of template impulse; 
% Recommended parameters:  loclzerr_CRC(50,0.01,0.02,25,1000);
% Copyright L. Yaroslavsky (yaro@eng.tau.ac.il)  
% Call OUT=loclzerr_CRC(Width,NSR0,DELTAnsr,Nnsr,Niter);

x=1:128;IMPULSE=exp(-((x-65).^2)/Width);
INTERVAL=128;
IMPULSE=reshape(IMPULSE,1,INTERVAL);
sp_sgn=conj(fft(IMPULSE));
f2=f2squar(IMPULSE); f2=sqrt(f2);

c=1:INTERVAL;
NSR=NSR0:DELTAnsr:NSR0+DELTAnsr*(Nnsr-1);
OUT=zeros(Nnsr,INTERVAL);
x=1:INTERVAL;x=x-INTERVAL/2-1;
std_err=zeros(Nnsr,1);
mean_err=zeros(Nnsr,1);
std_0=zeros(Nnsr,1);
figure_n(2);

for k=1:Nnsr,
    SIGNAL_0=IMPULSE/sqrt(sum(IMPULSE.^2));
    SIGNAL_n=SIGNAL_0+NSR(k)*randn(1,INTERVAL);
    figure(1);
    subplot(2,1,1)
    plot(x,SIGNAL_0,'k','LineWidth',2);
    hold on
    plot(x,SIGNAL_n,'k','LineWidth',1);
    grid on
    title(['Signal (bold line) and realization of signal+noise; NSR=',num2str(NSR(k))],'FontWeight','Bold')
    axis tight;
    set(gca,'FontWeight','Bold');
    drawnow
    hold off
    for n=1:Niter,
        SIGNAL_noise=IMPULSE/sqrt(sum(IMPULSE.^2))+NSR(k)*randn(1,INTERVAL);
        sp_noise=fft(SIGNAL_noise);
        corr=fftshift(real(ifft(sp_noise.*sp_sgn)));
        coord=max((corr==max(corr)).*c);
        OUT(k,coord)=OUT(k,coord)+1/Niter;
        std_err(k)=std_err(k)+(coord)^2;
        mean_err(k)=mean_err(k)+coord;
    end

    std_err(k)=(sqrt((std_err(k)/Niter)-(mean_err(k)/Niter).^2));
    std_0(k)=NSR(k)/(2*pi*f2);
    
%     NormErrDistr=max(OUT(k,:))*exp(-((x).^2)/(2*std_0(k)^2));
    figure(1);
    subplot(2,1,2)
    plot(x,OUT(k,:),'k','LineWidth',2);
    axis([-INTERVAL/2 INTERVAL/2-1 0 max(OUT(k,:))]);grid
    xlabel('Localization error','FontWeight','Bold')
    ylabel('Localization error distribution density','FontWeight','Bold');
    title(['NSR=',num2str(NSR(k))],'FontWeight','Bold');
    drawnow
    set(gca,'FontWeight','Bold');

%     std_err(k)=(sqrt((std_err(k)/Niter)-(mean_err(k)/Niter).^2));
%     std_0(k)=NSR(k)/(2*pi*f2);

    figure(2);
    plot(NSR',std_err,'k.',NSR',std_0,'k','LineWidth',2);
    xlabel('sqrt(\sigma^2_n/E_a)','FontWeight','Bold');
    ylabel('Std\_err/\Deltax','FontWeight','Bold');
    title('Standard deviation  of localization errors','FontWeight','Bold')
    grid on
    Xmax=max(NSR);
    Ymax=max(std_err);
    axis tight;
    drawnow
    set(gca,'FontWeight','Bold');
    legend('ErrorStDev','NormalErrStDev');
%     pause(2)
end
hold off
% OUT=[OUT std_err std_0];

%--------------------------------------------------
function OUT=f2squar(INP);

% Computation of the inertia moment of INP spectrum
% of a one-dimensional signal
% Call OUT=f2squar(INP);
% Copyright L. Yaroslavsky (yaro@eng.tau.ac.il)

[SzX SzY]=size(INP);
Sz=max(SzX, SzY);
sp=fftshift(abs(fft(INP)).^2);
sp=sp/sum(sp);

f2=(0:Sz-1);
f2=((f2-Sz/2)/Sz).^2;

OUT=sum(f2.*sp);



  